##  Bulk Linking Business Capability Fact Sheets
Bulk linking business capabilities from the inventory allows you to efficiently connect multiple fact sheets to catalog items. This method lets you review, link, and unlink fact sheets all in one place.
To link multiple fact sheets at once, follow these steps:
  1. On the navigation bar, click More > Reference Catalog > Business Capability Linking. Business capability fact sheets appear on the Unlinked and Linked tabs, depending on whether they're unlinked or linked to catalog items.
  2. On the Unlinked tab, select a business capability fact sheet, then search for and select a catalog item from the drop-down menu on the right that you want to link to the fact sheet. You can expand each row to view more details on each fact sheet and the matching catalog items.
  3. Click Link. To continue linking more fact sheets, repeat these steps.


![Linking Reference Business Architecture Items to Business Capability Fact Sheets in Bulk](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27557bc77a441014b4e9dde9e6c977b6_LowRes.png)
Linking Business Capability Fact Sheets to Catalog Items in Bulk
For some business capabilities, the Confidence column on the right provides a recommendation indicating the match level between the fact sheet and the catalog item. If you want to focus on fact sheets with high or medium confidence levels, use the Filter by confidence filter located next to the search field.
By expanding each row, you can view a summary of the fact sheet and details of the corresponding catalog item recommendation. If the recommendation doesn't align with your needs, use the search field to find a specific item to link to.
